@@ -49,7 +49,7 @@ class TestActionStepValidation:
             ("Setup uv", "Setup github2gerrit"),
             ("Checkout repository", "Run github2gerrit Python CLI"),
             ("Setup github2gerrit", "Run github2gerrit Python CLI"),
-            ("Run github2gerrit Python CLI", "Capture outputs (best-effort)"),
+            ("Run github2gerrit Python CLI", "Capture outputs"),
         ]
 
         for before_step, after_step in order_requirements:
@@ -221,9 +221,9 @@ class TestActionStepValidation:
         assert "uv --version" in script
         # Should contain both local installation and uvx logic
         assert "github.repository" in script
-        assert "modeseven-lfreleng-actions/github2gerrit-action" in script
+        assert "=~ lfreleng-actions/github2gerrit-action" in script
         assert "uv pip install --system ${{ github.action_path }}" in script
-        assert "Will use uvx to run latest PyPI release" in script
+        assert "uvx will install GitHub2Gerrit from PyPI" in script
 
     def test_cli_execution_step(self, action_config):
         """Test CLI execution step configuration."""
