@@ -39,6 +39,7 @@ def _minimal_inputs(*, dry_run: bool = False) -> Inputs:
         gerrit_server_port="29418",
         gerrit_project="example/project",
         issue_id="",
+        issue_id_lookup_json="",
         allow_duplicates=False,
         ci_testing=False,
     )
@@ -159,6 +160,7 @@ def test_resolve_gerrit_info_dry_run_uses_derived_project_when_missing(
         gerrit_server_port=inputs.gerrit_server_port,
         gerrit_project="",  # Missing, should derive from repo name
         issue_id=inputs.issue_id,
+        issue_id_lookup_json=inputs.issue_id_lookup_json,
         allow_duplicates=inputs.allow_duplicates,
         ci_testing=inputs.ci_testing,
     )
