@@ -15,6 +15,7 @@ from unittest import mock
 import pytest
 
 from github2gerrit.ssh_config_parser import SSHConfig
+from github2gerrit.ssh_config_parser import clear_credential_cache
 from github2gerrit.ssh_config_parser import derive_gerrit_credentials
 from github2gerrit.ssh_config_parser import get_git_user_email
 from github2gerrit.ssh_config_parser import get_ssh_user_for_gerrit
@@ -23,6 +24,10 @@ from github2gerrit.ssh_config_parser import get_ssh_user_for_gerrit
 class TestSSHConfig:
     """Test cases for SSH configuration parsing."""
 
+    def setup_method(self):
+        """Clear caches before each test to ensure isolation."""
+        clear_credential_cache()
+
     def test_empty_config(self, tmp_path):
         """Test handling of empty SSH config file."""
         config_file = tmp_path / "config"
@@ -298,6 +303,10 @@ HOST gerrit.example.com
 class TestConvenienceFunctions:
     """Test cases for convenience functions."""
 
+    def setup_method(self):
+        """Clear caches before each test to ensure isolation."""
+        clear_credential_cache()
+
     def test_get_ssh_user_for_gerrit(self, tmp_path):
         """Test the convenience function for getting Gerrit SSH user."""
         config_content = """
@@ -308,25 +317,23 @@ Host gerrit.*
         config_file = tmp_path / "config"
         config_file.write_text(config_content)
 
-        with mock.patch.object(SSHConfig, "__init__") as mock_init:
-            mock_init.return_value = None
-            ssh_config_instance = SSHConfig()
-            ssh_config_instance.config_path = config_file
-            ssh_config_instance._loaded = False
-            ssh_config_instance._parsed_config = []
-
-            with mock.patch(
-                "github2gerrit.ssh_config_parser.SSHConfig",
-                return_value=ssh_config_instance,
-            ):
-                user = get_ssh_user_for_gerrit("gerrit.linuxfoundation.org")
-                assert user == "gerrituser"
+        # Mock SSHConfig to use our temporary config file
+        with mock.patch(
+            "github2gerrit.ssh_config_parser.SSHConfig"
+        ) as mock_ssh_config:
+            mock_ssh_config.return_value = SSHConfig(config_path=config_file)
+            user = get_ssh_user_for_gerrit("gerrit.linuxfoundation.org")
+            assert user == "gerrituser"
 
+    @mock.patch("github2gerrit.ssh_config_parser._validate_git_executable")
     @mock.patch("subprocess.run")
     @mock.patch("shutil.which")
-    def test_get_git_user_email_success(self, mock_which, mock_run):
+    def test_get_git_user_email_success(
+        self, mock_which, mock_run, mock_validate
+    ):
         """Test successful git user email retrieval."""
         mock_which.return_value = "git"
+        mock_validate.return_value = True
         mock_run.return_value = mock.MagicMock(
             returncode=0, stdout="user@example.com\n"
         )
@@ -335,6 +342,7 @@ Host gerrit.*
         assert email == "user@example.com"
 
         mock_which.assert_called_once_with("git")
+        mock_validate.assert_called_once_with("git")
         mock_run.assert_called_once_with(
             ["git", "config", "user.email"],
             capture_output=True,
@@ -343,41 +351,160 @@ Host gerrit.*
             timeout=5,
         )
 
+    @mock.patch("github2gerrit.ssh_config_parser._validate_git_executable")
     @mock.patch("subprocess.run")
     @mock.patch("shutil.which")
-    def test_get_git_user_email_not_configured(self, mock_which, mock_run):
+    def test_get_git_user_email_not_configured(
+        self, mock_which, mock_run, mock_validate
+    ):
         """Test git user email when not configured."""
         mock_which.return_value = "git"
+        mock_validate.return_value = True
         mock_run.return_value = mock.MagicMock(returncode=1, stdout="")
 
         email = get_git_user_email()
         assert email is None
 
+    @mock.patch("github2gerrit.ssh_config_parser._validate_git_executable")
     @mock.patch("subprocess.run")
     @mock.patch("shutil.which")
-    def test_get_git_user_email_command_not_found(self, mock_which, mock_run):
+    def test_get_git_user_email_command_not_found(
+        self, mock_which, mock_run, mock_validate
+    ):
         """Test git user email when git command not found."""
         mock_which.return_value = None
 
         email = get_git_user_email()
         assert email is None
 
+        mock_which.assert_called_once_with("git")
+        mock_validate.assert_not_called()
+
+    @mock.patch("github2gerrit.ssh_config_parser._validate_git_executable")
     @mock.patch("subprocess.run")
     @mock.patch("shutil.which")
-    def test_get_git_user_email_timeout(self, mock_which, mock_run):
+    def test_get_git_user_email_validation_failed(
+        self, mock_which, mock_run, mock_validate
+    ):
+        """Test git user email when git validation fails."""
+        mock_which.return_value = "/fake/git"
+        mock_validate.return_value = False
+
+        email = get_git_user_email()
+        assert email is None
+
+        mock_which.assert_called_once_with("git")
+        mock_validate.assert_called_once_with("/fake/git")
+        mock_run.assert_not_called()
+
+    @mock.patch("github2gerrit.ssh_config_parser._validate_git_executable")
+    @mock.patch("subprocess.run")
+    @mock.patch("shutil.which")
+    def test_get_git_user_email_timeout(
+        self, mock_which, mock_run, mock_validate
+    ):
         """Test git user email with timeout."""
         mock_which.return_value = "git"
+        mock_validate.return_value = True
         mock_run.side_effect = subprocess.TimeoutExpired("git", 5)
 
         email = get_git_user_email()
         assert email is None
 
+    def test_validate_git_executable_valid_git(self):
+        """Test git executable validation with actual git."""
+        import shutil
+
+        from github2gerrit.ssh_config_parser import _validate_git_executable
+
+        git_path = shutil.which("git")
+        if git_path:
+            # Should validate successfully with real git
+            assert _validate_git_executable(git_path) is True
+        else:
+            pytest.skip("Git not available in PATH")
+
+    def test_validate_git_executable_invalid_path(self):
+        """Test git executable validation with invalid path."""
+        from github2gerrit.ssh_config_parser import _validate_git_executable
+
+        # Non-existent path should fail
+        assert _validate_git_executable("/nonexistent/path/to/git") is False
+
+    @mock.patch("subprocess.run")
+    def test_validate_git_executable_not_git(self, mock_run):
+        """Test git executable validation with non-git executable."""
+        import os
+        import tempfile
+
+        from github2gerrit.ssh_config_parser import _validate_git_executable
+
+        # Create a temporary executable file that's not git
+        with tempfile.NamedTemporaryFile(
+            mode="w", delete=False, suffix="_fake_git"
+        ) as f:
+            f.write('#!/bin/bash\necho "fake program"\n')
+            fake_git_path = f.name
+
+        try:
+            # Make it executable
+            os.chmod(
+                fake_git_path, 0o700
+            )  # More restrictive permissions for test
+
+            # Mock subprocess to return non-git output
+            mock_run.return_value = mock.MagicMock(
+                returncode=0, stdout="fake program version 1.0"
+            )
+
+            # Should fail validation since it doesn't respond like git
+            assert _validate_git_executable(fake_git_path) is False
+
+        finally:
+            os.unlink(fake_git_path)
+
+    @mock.patch("subprocess.run")
+    def test_validate_git_executable_timeout(self, mock_run):
+        """Test git executable validation with timeout."""
+        import os
+        import subprocess
+        import tempfile
+
+        from github2gerrit.ssh_config_parser import _validate_git_executable
+
+        # Create a temporary executable file
+        with tempfile.NamedTemporaryFile(
+            mode="w", delete=False, suffix="_timeout_git"
+        ) as f:
+            f.write("#!/bin/bash\nsleep 10\n")
+            fake_git_path = f.name
+
+        try:
+            # Make it executable
+            os.chmod(
+                fake_git_path, 0o700
+            )  # More restrictive permissions for test
+
+            # Mock subprocess to timeout
+            mock_run.side_effect = subprocess.TimeoutExpired("fake_git", 3)
+
+            # Should fail validation on timeout
+            assert _validate_git_executable(fake_git_path) is False
+
+        finally:
+            os.unlink(fake_git_path)
+
 
 class TestCredentialDerivation:
     """Test cases for credential derivation logic."""
 
+    def setup_method(self):
+        """Clear caches before each test to ensure isolation."""
+        clear_credential_cache()
+
     @mock.patch("github2gerrit.ssh_config_parser.get_git_user_email")
     @mock.patch("github2gerrit.ssh_config_parser.get_ssh_user_for_gerrit")
+    @mock.patch.dict("os.environ", {"G2G_RESPECT_USER_SSH": "true"})
     def test_derive_gerrit_credentials_ssh_and_git(
         self, mock_ssh_user, mock_git_email
     ):
@@ -395,6 +522,7 @@ class TestCredentialDerivation:
 
     @mock.patch("github2gerrit.ssh_config_parser.get_git_user_email")
     @mock.patch("github2gerrit.ssh_config_parser.get_ssh_user_for_gerrit")
+    @mock.patch.dict("os.environ", {"G2G_RESPECT_USER_SSH": "true"})
     def test_derive_gerrit_credentials_ssh_only(
         self, mock_ssh_user, mock_git_email
     ):
@@ -409,6 +537,7 @@ class TestCredentialDerivation:
 
     @mock.patch("github2gerrit.ssh_config_parser.get_git_user_email")
     @mock.patch("github2gerrit.ssh_config_parser.get_ssh_user_for_gerrit")
+    @mock.patch.dict("os.environ", {"G2G_RESPECT_USER_SSH": "true"})
     def test_derive_gerrit_credentials_git_only(
         self, mock_ssh_user, mock_git_email
     ):
@@ -435,6 +564,7 @@ class TestCredentialDerivation:
         assert user == "testorg.gh2gerrit"
         assert email == "releng+testorg-gh2gerrit@linuxfoundation.org"
 
+    @mock.patch.dict("os.environ", {"G2G_RESPECT_USER_SSH": "true"})
     def test_derive_gerrit_credentials_custom_port(self):
         """Test credential derivation with custom port."""
         with (
@@ -461,6 +591,10 @@ class TestCredentialDerivation:
 class TestPatternMatching:
     """Test cases for SSH host pattern matching."""
 
+    def setup_method(self):
+        """Clear caches before each test to ensure isolation."""
+        clear_credential_cache()
+
     def test_pattern_matching_exact(self):
         """Test exact host pattern matching."""
         ssh_config = SSHConfig()
@@ -557,6 +691,10 @@ class TestPatternMatching:
 class TestConfigLineHandling:
     """Test cases for SSH config line parsing."""
 
+    def setup_method(self):
+        """Clear caches before each test to ensure isolation."""
+        clear_credential_cache()
+
     def test_split_config_line_basic(self):
         """Test basic config line splitting."""
         ssh_config = SSHConfig()
@@ -630,6 +768,11 @@ Host *
 class TestIntegration:
     """Integration tests using realistic configurations."""
 
+    def setup_method(self):
+        """Clear caches before each test to ensure isolation."""
+        clear_credential_cache()
+
+    @mock.patch.dict("os.environ", {"G2G_RESPECT_USER_SSH": "true"})
     def test_lfit_organization_config(self, tmp_path, sample_ssh_config):
         """Test credential derivation for lfit organization with real SSH config."""
         config_file = tmp_path / "config"
@@ -655,6 +798,7 @@ class TestIntegration:
                 assert user == "gerritbot"
                 assert email == "user@example.org"
 
+    @mock.patch.dict("os.environ", {"G2G_RESPECT_USER_SSH": "true"})
     def test_unknown_organization_fallback(self, tmp_path, sample_ssh_config):
         """Test fallback behavior for unknown organization."""
         config_file = tmp_path / "config"
@@ -682,3 +826,97 @@ class TestIntegration:
                 assert (
                     email == "releng+unknownorg-gh2gerrit@linuxfoundation.org"
                 )
+
+
+class TestCaching:
+    """Test cases for caching behavior in SSH config parsing and credential derivation."""
+
+    def setup_method(self):
+        """Clear caches before each test to ensure isolation."""
+        clear_credential_cache()
+
+    @mock.patch("github2gerrit.ssh_config_parser.get_git_user_email")
+    @mock.patch("github2gerrit.ssh_config_parser.get_ssh_user_for_gerrit")
+    @mock.patch("github2gerrit.ssh_config_parser._get_respect_user_ssh_setting")
+    def test_derive_gerrit_credentials_caching(
+        self, mock_respect_ssh, mock_ssh_user, mock_git_email
+    ):
+        """Test that derive_gerrit_credentials caches results to avoid repeated calls."""
+        # Set up mocks to enable SSH config usage
+        mock_respect_ssh.return_value = True
+        mock_ssh_user.return_value = "sshuser"
+        mock_git_email.return_value = "user@example.com"
+
+        # Call the function twice with the same parameters
+        user1, email1 = derive_gerrit_credentials(
+            "gerrit.example.com", "testorg"
+        )
+        user2, email2 = derive_gerrit_credentials(
+            "gerrit.example.com", "testorg"
+        )
+
+        # Results should be identical
+        assert user1 == user2 == "sshuser"
+        assert email1 == email2 == "user@example.com"
+
+        # The underlying functions should only be called once due to caching
+        # Note: mock_respect_ssh will be called twice because it's also cached separately
+        assert mock_ssh_user.call_count == 1
+        assert mock_git_email.call_count == 1
+
+    @mock.patch("github2gerrit.ssh_config_parser.env_bool")
+    def test_respect_user_ssh_setting_caching(self, mock_env_bool):
+        """Test that G2G_RESPECT_USER_SSH environment variable is cached."""
+        mock_env_bool.return_value = True
+
+        # Import the cached function
+        from github2gerrit.ssh_config_parser import (
+            _get_respect_user_ssh_setting,
+        )
+
+        # Call multiple times
+        result1 = _get_respect_user_ssh_setting()
+        result2 = _get_respect_user_ssh_setting()
+        result3 = _get_respect_user_ssh_setting()
+
+        # All should return the same value
+        assert result1 == result2 == result3 is True
+
+        # env_bool should only be called once due to caching
+        assert mock_env_bool.call_count == 1
+
+    def test_clear_credential_cache_functionality(self):
+        """Test that clear_credential_cache properly clears all caches."""
+        # Import the cache clearing function and cached functions
+        from github2gerrit.ssh_config_parser import _get_cached_git_user_email
+        from github2gerrit.ssh_config_parser import (
+            _get_respect_user_ssh_setting,
+        )
+        from github2gerrit.ssh_config_parser import clear_credential_cache
+
+        # Call functions to populate caches (using mocks to avoid actual system calls)
+        with mock.patch(
+            "github2gerrit.ssh_config_parser.env_bool"
+        ) as mock_env_bool:
+            mock_env_bool.return_value = True
+            _get_respect_user_ssh_setting()
+
+        with mock.patch(
+            "github2gerrit.ssh_config_parser.get_git_user_email"
+        ) as mock_git_email:
+            mock_git_email.return_value = "test@example.com"
+            _get_cached_git_user_email()
+
+        with mock.patch(
+            "github2gerrit.ssh_config_parser.get_ssh_user_for_gerrit"
+        ) as mock_ssh_user:
+            mock_ssh_user.return_value = "testuser"
+            derive_gerrit_credentials("gerrit.example.com", "testorg")
+
+        # Clear all caches
+        clear_credential_cache()
+
+        # Verify caches are cleared by checking cache info
+        assert _get_respect_user_ssh_setting.cache_info().currsize == 0
+        assert _get_cached_git_user_email.cache_info().currsize == 0
+        assert derive_gerrit_credentials.cache_info().currsize == 0
